@@ -10,7 +10,7 @@ use Net::HL7::Connection;
 use Net::HL7::Message;
 use Perl6::Slurp qw(slurp);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -22,6 +22,14 @@ sub new {
 	# Process params.
 	set_params($self, @params);
 
+	# Object.
+	return $self;
+}
+
+# Run.
+sub run {
+	my $self = shift;
+
 	# Process arguments.
 	$self->{'_opts'} = {
 		'h' => 0,
@@ -30,22 +38,14 @@ sub new {
 		|| $self->{'_opts'}->{'h'}) {
 
 		print STDERR "Usage: $0 [-h] [--version] host port hl7_file|-\n";
-		print STDERR "\t-h\t\tHelp.\n";
+		print STDERR "\t-h\t\tPrint help.\n";
 		print STDERR "\t--version\tPrint version.\n";
-		exit 1;
+		return 1;
 	}
 	$self->{'_hl7_host'} = $ARGV[0];
 	$self->{'_hl7_port'} = $ARGV[1];
 	$self->{'_hl7_file'} = $ARGV[2];
 
-	# Object.
-	return $self;
-}
-
-# Run.
-sub run {
-	my $self = shift;
-
 	# Get hl7_file.
 	my $hl7;
 	if ($self->{'_hl7_file'} eq '-') {
@@ -186,11 +186,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2016-2018 Michal Josef Špaček
- BSD 2-Clause License
+© 2016-2022 Michal Josef Špaček
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
